.. _view_module:

:mod:`pyramid.view`
----------------------

.. automodule:: pyramid.view

  .. autofunction:: render_view_to_response

  .. autofunction:: render_view_to_iterable

  .. autofunction:: render_view

  .. autofunction:: is_response

  .. autoclass:: view_config
     :members:

  .. autoclass:: static
     :members:
     :inherited-members:

  .. autofunction:: append_slash_notfound_view(context, request)

  .. autoclass:: AppendSlashNotFoundViewFactory

